@@ -1,6 +1,6 @@
 import logging
 from fractions import Fraction
-from dispatch import InstanceMethodDispatch
+from dftt_dispatch import InstanceMethodDispatch
 from error import DFTTTimecodeValueError, DFTTTimecodeTypeError
 from pattern import *
 from math import ceil
